# DeckSmith

A command-line application to dynamically generate decks of cards from a JSON specification and a CSV data file, inspired by nandeck.

DeckSmith is ideal for automating the creation of all kinds of decks, including TCG decks, tarot decks, business cards, and even slides.

## Features

- Initialize a sample project and edit it instead of starting from scratch.

- Include images, text, and different kinds of shapes.

- Link any field to a column in the CSV file.

- Position elements absolutely or relative to other elements, using anchors to simplify placement

- Transform images using filters like crop, resize, rotate, or flip.

- Build card images and export to PDF for printing.

## Getting started

To start creating decks, check out [Getting Started](DOCS.md/#getting-started).
